==> fsk_frontend-01.7.tar.gz: fsk_frontend/.miyagi.js <==
module.exports = {
  assets: {
    css: [
      "css/index.css",
      "https://factorial-io.github.io/css-highlighter/index.css",
    ],
    customProperties: {
      files: ["css/tokens.css"],
    },
    folder: ["fonts", "css", "templates"],
  },
  components: {
    folder: "templates",
  },
  engine: {
    name: "twig",
    options: {
      namespaces: {
        fsk: "templates",
      },
    },
  },

  extensions: [require("@miyagi/twig-drupal")],
  files: {
    css: {
      name: "<component>",
    },
    info: {
      extension: "yaml",
    },
    js: {
      name: "<component>",
    },
    mocks: {
      extension: "yaml",
    },
    templates: {
      extension: "html.twig",
      name: "<component>",
    },
    schema: {
      extension: "yaml",
    },
  },
  projectName: "Frontend Starter Kit",
  ui: {
    theme: {
      logo: "https://logo.factorial.io/color.png",
      fontFamily: "Roboto",
      navigation: {
        colorBackground: "#012954",
        colorLinks: "#deebff",
        colorLinksActive: "#012954",
      },
      content: {
        colorHeadlines: "#172b4d",
      },
      css: `
        @import "https://fonts.googleapis.com/css2?family=Roboto:ital,wght@0,400;0,700;1,400;1,700&display=swap";
        body {
          font-family: Roboto, sans-serif;
          line-height: 1.5;
        }
        @media (min-width: 40.0625em) {
          .Miyagi-projectLogo {
            width: 5rem;
            height: 7rem;
          }
        }
      `,
    },
    validations: {
      html: false,
    },
  },
  schema: {
    strict: false,
    formats: {
      html: true,
      "uri-reference": true,
    },
  },
};

==> fsk_frontend-02.0.tar.gz: fsk_frontend/.miyagi.js <==
module.exports = {
  assets: {
    css: {
      development: [
        "css/index.css",
        "https://factorial-io.github.io/css-highlighter/index.css",
      ],
      production: "build/assets/css/index.css",
    },
    customProperties: {
      files: ["css/tokens.css"],
    },
    folder: {
      development: ["fonts", "css", "templates"],
      production: ["fonts", "css"],
    },
  },
  components: {
    folder: "templates",
  },
  engine: {
    name: "twig",
    options: {
      namespaces: {
        fsk: "templates",
      },
    },
  },
  build: {
    folder: "build/miyagi",
  },
  extensions: [require("@miyagi/twig-drupal")],
  files: {
    css: {
      name: "<component>",
    },
    info: {
      extension: "yaml",
    },
    js: {
      name: "<component>",
    },
    mocks: {
      extension: "yaml",
    },
    templates: {
      extension: "html.twig",
      name: "<component>",
    },
    schema: {
      extension: "yaml",
    },
  },
  projectName: "Frontend Starter Kit",
  ui: {
    theme: {
      logo: "https://logo.factorial.io/color.png",
      fontFamily: "Roboto",
      navigation: {
        colorBackground: "#012954",
        colorLinks: "#deebff",
        colorLinksActive: "#012954",
      },
      content: {
        colorHeadlines: "#172b4d",
      },
      css: `
        @import "https://fonts.googleapis.com/css2?family=Roboto:ital,wght@0,400;0,700;1,400;1,700&display=swap";
        body {
          font-family: Roboto, sans-serif;
          line-height: 1.5;
        }
        @media (min-width: 40.0625em) {
          .Miyagi-projectLogo {
            width: 5rem;
            height: 7rem;
          }
        }
      `,
    },
    validations: {
      html: false,
    },
  },
  schema: {
    strict: false,
    formats: {
      html: true,
      "uri-reference": true,
    },
  },
};
